<?php

namespace Drupal\user_bulk_delete\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class declaration.
 */
class UserBulkDeleteController extends ControllerBase {

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a UserBulkDeleteController object.
   *
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   */
  public function __construct(FormBuilderInterface $form_builder) {
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('form_builder')
    );
  }

  /**
   * List users who have logged in less than 5 times.
   */
  public function listUsers() {
    $database = \Drupal::database();

    // Query to select user IDs, names, and login counts of users who have logged in less than 5 times, excluding user ID 1.
    $query = $database->select('user__login_count', 'lc')
      ->fields('lc', ['entity_id', 'login_count_value'])
      ->condition('lc.login_count_value', 5, '<')
      ->condition('lc.entity_id', 1, '!=');
    $query->join('users_field_data', 'u', 'u.uid = lc.entity_id');
    $query->fields('u', ['uid', 'name']);

    $results = $query->execute()->fetchAll();

    if (empty($results)) {
      $this->messenger()->addMessage($this->t('No users found with less than 5 logins.'));
      return ['#markup' => $this->t('No users found with less than 5 logins.')];
    }

    $rows = [];
    foreach ($results as $result) {
      $rows[] = [
        'data' => [
          'uid' => $result->uid,
          'name' => $result->name,
          'login_count' => $result->login_count_value,
        ],
      ];
    }

    $build['user_list'] = [
      '#type' => 'table',
      '#header' => [$this->t('User ID'), $this->t('Username'), $this->t('Login Count')],
      '#rows' => $rows,
    ];

    $build['delete_form'] = $this->formBuilder->getForm('\Drupal\user_bulk_delete\Form\UserBulkDeleteConfirmForm', $results);

    return $build;
  }

}
